from wagtail.blocks import *
from wagtail.images.blocks import ImageChooserBlock
from wagtail.admin.panels import FieldPanel, MultiFieldPanel, FieldRowPanel
from wagtailmodelchooser.blocks import ModelChooserBlock
# from Core.models import ExportCountry
from wagtail_color_panel.blocks import NativeColorBlock
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail.contrib.table_block.blocks import TableBlock
from wagtailcodeblock.blocks import CodeBlock

from Core.baseSettings import *


class CarouselBlock(StructBlock):
    height = IntegerBlock(default=200, min=150, max=400)
    width = IntegerBlock(default=400, min=350, max=600)
    timer = IntegerBlock(default=2000, help_text="Slide time in ms")
    content = StreamBlock(
        [
            ('slide', StructBlock([
                ("image", ImageChooserBlock(required=True)),
                ("title", CharBlock(required=False)),
            ]))
        ]
    )


class BlogSocialBlock(StructBlock):
    slName = ModelChooserBlock('Core.SocialPlatform', label="Social platform")
    blsUrl = URLBlock(required=False, label='URL')


class BlogGalleryBlock(StructBlock):
    image = ImageChooserBlock(required=False)
    caption = CharBlock(required=False)


class ParagraphBlock(StructBlock):
    text = RichTextBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST,
                             required=False, label="Line Spacing")


class HeadingBlock(StructBlock):
    title = CharBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    Panels = [
        MultiFieldPanel([
            FieldRowPanel([
                FieldPanel('alignment'),
                FieldPanel('size')

            ])
        ])
    ]


class SocialBlock(StreamBlock):
    social_link = ModelChooserBlock('Core.SocialLinks')


class ComInfoBlock(StreamBlock):
    info = ModelChooserBlock('Core.CompanyInfo')


class AccordionTitleBlock(StructBlock):
    title = CharBlock()
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)


class AccordionDetailBlock(StructBlock):
    desc = RichTextBlock()
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST, required=False)


class AccordBlock(StructBlock):
    title = AccordionTitleBlock()
    detail = AccordionDetailBlock()


class AccordionBlock(StreamBlock):
    accord_items = AccordBlock()


class QuoteBlock(StructBlock):
    quote = BlockQuoteBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False)
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False)
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST, required=False)


class BaseColumnBlock(StructBlock):
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    content = StreamBlock([
        ("heading", HeadingBlock(required=False)),
        ("paragraph", ParagraphBlock(required=False)),
        ("code", CodeBlock(required=False, label='Code')),
        ("quote", QuoteBlock(required=False)),
        ("image", ImageChooserBlock(required=False)),
        ('accordion', AccordionBlock(required=False)),
        ("link", PageChooserBlock(required=False)),
        ("image_Text", BlogGalleryBlock(required=False)),
    ])


class BaseRowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#000000", label="BG Color")
    fgColor = NativeColorBlock(default="#FFFFFF", label="FG Color")
    title = CharBlock(required=False)
    content = StreamBlock(
        [
            ("column", BaseColumnBlock(required=False))
        ], required=False
    )


class ColumnBlock(StructBlock):
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    width = CharBlock(default="50%", required=False)
    content = StreamBlock([
        ("heading", HeadingBlock(required=False)),
        ("paragraph", ParagraphBlock(required=False)),
        ("code", CodeBlock(required=False, label='Code')),
        ("quote", QuoteBlock(required=False)),
        ("image", ImageChooserBlock(required=False)),
        ("sub_row", BaseRowBlock(required=False)),
        ('accordion', AccordionBlock(required=False)),
        ("link", PageChooserBlock(required=False)),
        ("image_Text", BlogGalleryBlock(required=False)),

    ], required=False)


# Main Blocks


class RowBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("column", ColumnBlock(required=False))
        ], required=False
    )


class SectionBlock(StructBlock):
    bgColor = NativeColorBlock(default="#FFFFFF", label="BG Color")
    fgColor = NativeColorBlock(default="#000000", label="FG Color")
    fontType = ChoiceBlock(choices=FONT_TYPE_LIST, required=False)
    title = CharBlock(required=False)

    content = StreamBlock(
        [
            ("heading", HeadingBlock(required=False)),
            ("paragraph", ParagraphBlock(required=False)),
            ("code", CodeBlock(required=False, label='Code')),
            ("quote", QuoteBlock(required=False)),
            ("image", ImageChooserBlock(required=False)),
            ("accordion", AccordionBlock(required=False)),
            ("link", PageChooserBlock(required=False)),
            ("image_Text", BlogGalleryBlock(required=False)),

        ], required=False
    )
    # class Meta:
    #     icon = 'user'
